==> code_saturne-8.1.1-3-x86_64.pkg.tar.zst: usr/share/doc/code_saturne/doxygen/src/cs__solidification_8h.js <==
var cs__solidification_8h =
[
    [ "cs_solidification_stefan_t", "structcs__solidification__stefan__t.html", "structcs__solidification__stefan__t" ],
    [ "cs_solidification_voller_t", "structcs__solidification__voller__t.html", "structcs__solidification__voller__t" ],
    [ "cs_solidification_binary_alloy_t", "structcs__solidification__binary__alloy__t.html", "structcs__solidification__binary__alloy__t" ],
    [ "cs_solidification_t", "structcs__solidification__t.html", "structcs__solidification__t" ],
    [ "CS_SOLIDIFICATION_ADVANCED_ANALYSIS", "cs__solidification_8h.html#aac2c33ac4118cdf030ba2d32811ce3af", null ],
    [ "CS_SOLIDIFICATION_BINARY_ALLOY_C_FUNC", "cs__solidification_8h.html#a18d6c0b9231f14e21602f31924869616", null ],
    [ "CS_SOLIDIFICATION_BINARY_ALLOY_G_FUNC", "cs__solidification_8h.html#af083185205544aad8e0275622ec029c2", null ],
    [ "CS_SOLIDIFICATION_BINARY_ALLOY_M_FUNC", "cs__solidification_8h.html#a4ad3bc4021e58d5ac90f1f1383089503", null ],
    [ "CS_SOLIDIFICATION_BINARY_ALLOY_T_FUNC", "cs__solidification_8h.html#afecdce45da214cb0a31f0a73ac266f0e", null ],
    [ "CS_SOLIDIFICATION_NO_VELOCITY_FIELD", "cs__solidification_8h.html#a49dedb2f7038ab7dd6dba71ab9b81a33", null ],
    [ "CS_SOLIDIFICATION_POST_CBULK_ADIM", "cs__solidification_8h.html#a09da5af8b74efa13e23f06e0f46d0000", null ],
    [ "CS_SOLIDIFICATION_POST_CELL_STATE", "cs__solidification_8h.html#aea5450b6b765c331a07fa7962082c0ae", null ],
    [ "CS_SOLIDIFICATION_POST_CLIQ", "cs__solidification_8h.html#a4281f391ffcd35077493fb4417728b59", null ],
    [ "CS_SOLIDIFICATION_POST_ENTHALPY", "cs__solidification_8h.html#aa45423a24ad5085693c938c292c12de9", null ],
    [ "CS_SOLIDIFICATION_POST_LIQUIDUS_TEMPERATURE", "cs__solidification_8h.html#aeedd83381c81f7bfbd992497800ab46c", null ],
    [ "CS_SOLIDIFICATION_POST_SEGREGATION_INDEX", "cs__solidification_8h.html#a5d25238383ba868c2f7f02a17eb44ab5", null ],
    [ "CS_SOLIDIFICATION_POST_SOLIDIFICATION_RATE", "cs__solidification_8h.html#ab6951ea065c7eceb1b161d92ea1bd3f5", null ],
    [ "CS_SOLIDIFICATION_USE_ENTHALPY_VARIABLE", "cs__solidification_8h.html#a4445fb75dac9ac4fdc4b6e56ddf705d4", null ],
    [ "CS_SOLIDIFICATION_USE_EXTRAPOLATION", "cs__solidification_8h.html#a0bfe68a6b794ad5280f3170868d7da06", null ],
    [ "CS_SOLIDIFICATION_WITH_PENALIZED_EUTECTIC", "cs__solidification_8h.html#a8694553071cca34d462ab4027d999d31", null ],
    [ "CS_SOLIDIFICATION_WITH_SOLUTE_SOURCE_TERM", "cs__solidification_8h.html#aab5002e17d27ed33b5803db5558e47b2", null ],
    [ "cs_solidification_func_t", "cs__solidification_8h.html#a426edc9b4c370bf2d60143bc28b700fb", null ],
    [ "cs_solidification_model_t", "cs__solidification_8h.html#a847fc9cd88ade8ed8fec05302493283e", [
      [ "CS_SOLIDIFICATION_MODEL_STEFAN", "cs__solidification_8h.html#a847fc9cd88ade8ed8fec05302493283ead310f2165a98a65537bc44be2a1e96ea", null ],
      [ "CS_SOLIDIFICATION_MODEL_VOLLER_PRAKASH_87", "cs__solidification_8h.html#a847fc9cd88ade8ed8fec05302493283ea72f4e36c43398be62f5f82d1eb4001a0", null ],
      [ "CS_SOLIDIFICATION_MODEL_VOLLER_NL", "cs__solidification_8h.html#a847fc9cd88ade8ed8fec05302493283ea5777c96d7b0146f9ab97487956edf7dd", null ],
      [ "CS_SOLIDIFICATION_MODEL_BINARY_ALLOY", "cs__solidification_8h.html#a847fc9cd88ade8ed8fec05302493283ea23776cc28184da5c0a1e18793d3d6632", null ],
      [ "CS_SOLIDIFICATION_N_MODELS", "cs__solidification_8h.html#a847fc9cd88ade8ed8fec05302493283eacd06fa59042aac5c895f36a76add9538", null ]
    ] ],
    [ "cs_solidification_state_t", "cs__solidification_8h.html#ab4298ec32d264db8112dea50e5497c3b", [
      [ "CS_SOLIDIFICATION_STATE_SOLID", "cs__solidification_8h.html#ab4298ec32d264db8112dea50e5497c3ba11d553eb8fd223ae636d904153c39a2d", null ],
      [ "CS_SOLIDIFICATION_STATE_MUSHY", "cs__solidification_8h.html#ab4298ec32d264db8112dea50e5497c3bae70b73f5c817cae2861dccd7ab876f45", null ],
      [ "CS_SOLIDIFICATION_STATE_LIQUID", "cs__solidification_8h.html#ab4298ec32d264db8112dea50e5497c3bade547a363b4a7a0076c7f61ea30ac792", null ],
      [ "CS_SOLIDIFICATION_STATE_EUTECTIC", "cs__solidification_8h.html#ab4298ec32d264db8112dea50e5497c3bae842024a96a086121827d561cd1cbead", null ],
      [ "CS_SOLIDIFICATION_N_STATES", "cs__solidification_8h.html#ab4298ec32d264db8112dea50e5497c3ba366ae1d85364e535f851936de75362a8", null ]
    ] ],
    [ "cs_solidification_strategy_t", "cs__solidification_8h.html#a9a11ab690b2f45b6712298ef199781a4", [
      [ "CS_SOLIDIFICATION_STRATEGY_LEGACY", "cs__solidification_8h.html#a9a11ab690b2f45b6712298ef199781a4a0d611113cda237cf3b2cbf29e983e830", null ],
      [ "CS_SOLIDIFICATION_STRATEGY_TAYLOR", "cs__solidification_8h.html#a9a11ab690b2f45b6712298ef199781a4a0db3938bb891879d3451acece02147b3", null ],
      [ "CS_SOLIDIFICATION_STRATEGY_PATH", "cs__solidification_8h.html#a9a11ab690b2f45b6712298ef199781a4a719293aeb828af4bf0463201698eca75", null ],
      [ "CS_SOLIDIFICATION_N_STRATEGIES", "cs__solidification_8h.html#a9a11ab690b2f45b6712298ef199781a4aa0a322acbffdc3cb958d6801d261abcd", null ]
    ] ],
    [ "cs_solidification_activate", "cs__solidification_8h.html#a7d1a091d66ba46c823f06f8701d1099f", null ],
    [ "cs_solidification_check_binary_alloy_model", "cs__solidification_8h.html#a89dd2bdcf8f6518aa81f014da2204674", null ],
    [ "cs_solidification_check_stefan_model", "cs__solidification_8h.html#a25c9a517bf20ac6f6e67339c365adc52", null ],
    [ "cs_solidification_check_voller_model", "cs__solidification_8h.html#a68ae983504411db82d2353f003778a60", null ],
    [ "cs_solidification_compute", "cs__solidification_8h.html#a0f489dec0463d2309d825df87c68a3b5", null ],
    [ "cs_solidification_destroy_all", "cs__solidification_8h.html#aececbfa25ad9cb0879785727ba613875", null ],
    [ "cs_solidification_extra_op", "cs__solidification_8h.html#a5a119e288d9de10dba56cbc7383267aa", null ],
    [ "cs_solidification_extra_post", "cs__solidification_8h.html#aafad3b15b18f023f7b253f1c4b897f6c", null ],
    [ "cs_solidification_finalize_setup", "cs__solidification_8h.html#a9ed273ffbebed1f2113505272c403d68", null ],
    [ "cs_solidification_get_binary_alloy_struct", "cs__solidification_8h.html#a6201346c2c1174da4d6847dcea6dcdfe", null ],
    [ "cs_solidification_get_stefan_struct", "cs__solidification_8h.html#af3a6f646d1c0f211d830f85371a58710", null ],
    [ "cs_solidification_get_structure", "cs__solidification_8h.html#affe33d3a74b094a1f80993a8ebb45caf", null ],
    [ "cs_solidification_get_voller_struct", "cs__solidification_8h.html#a9e3ba554cb187723f757e208308e4f94", null ],
    [ "cs_solidification_init_setup", "cs__solidification_8h.html#a8aed8bf87ab13a52b0c8ed86d2d53a43", null ],
    [ "cs_solidification_init_values", "cs__solidification_8h.html#a5eaa7753944eb64e8192269b8d61d1e8", null ],
    [ "cs_solidification_is_activated", "cs__solidification_8h.html#ac9b4ea778d6477e677e68701a8ad4321", null ],
    [ "cs_solidification_log_setup", "cs__solidification_8h.html#accdf9de2c4023ba069d188860608eceb", null ],
    [ "cs_solidification_set_binary_alloy_model", "cs__solidification_8h.html#a97f07f1b940fa53c49cbba2b871a0762", null ],
    [ "cs_solidification_set_forcing_eps", "cs__solidification_8h.html#aed23a16562befe5af4b712c242b0a92c", null ],
    [ "cs_solidification_set_segr_functions", "cs__solidification_8h.html#ae42bba458637466963a9490e8b7aa8fd", null ],
    [ "cs_solidification_set_stefan_model", "cs__solidification_8h.html#aca386eb2d86482c2e6edd0f2e810ecb0", null ],
    [ "cs_solidification_set_strategy", "cs__solidification_8h.html#a1d002dac39889533773667f013057a7e", null ],
    [ "cs_solidification_set_verbosity", "cs__solidification_8h.html#aa039315ac787bf70f473c3210468ab9b", null ],
    [ "cs_solidification_set_voller_model", "cs__solidification_8h.html#a2dde78f51a0f69cd336fcb2095909f01", null ],
    [ "cs_solidification_set_voller_model_no_velocity", "cs__solidification_8h.html#ad386378ffef1a53c1d782431bdeb41fc", null ]
];

==> code_saturne-9.1.0-1-x86_64.pkg.tar.zst: usr/share/doc/code_saturne/doxygen/src/cs__solidification_8h.js <==
var cs__solidification_8h =
[
    [ "cs_solidification_stefan_t", "structcs__solidification__stefan__t.html", "structcs__solidification__stefan__t" ],
    [ "cs_solidification_voller_t", "structcs__solidification__voller__t.html", "structcs__solidification__voller__t" ],
    [ "cs_solidification_binary_alloy_t", "structcs__solidification__binary__alloy__t.html", "structcs__solidification__binary__alloy__t" ],
    [ "cs_solidification_t", "structcs__solidification__t.html", "structcs__solidification__t" ],
    [ "CS_SOLIDIFICATION_ADVANCED_ANALYSIS", "cs__solidification_8h.html#aac2c33ac4118cdf030ba2d32811ce3af", null ],
    [ "CS_SOLIDIFICATION_BINARY_ALLOY_C_FUNC", "cs__solidification_8h.html#a18d6c0b9231f14e21602f31924869616", null ],
    [ "CS_SOLIDIFICATION_BINARY_ALLOY_G_FUNC", "cs__solidification_8h.html#af083185205544aad8e0275622ec029c2", null ],
    [ "CS_SOLIDIFICATION_BINARY_ALLOY_M_FUNC", "cs__solidification_8h.html#a4ad3bc4021e58d5ac90f1f1383089503", null ],
    [ "CS_SOLIDIFICATION_BINARY_ALLOY_T_FUNC", "cs__solidification_8h.html#afecdce45da214cb0a31f0a73ac266f0e", null ],
    [ "CS_SOLIDIFICATION_NO_VELOCITY_FIELD", "cs__solidification_8h.html#a49dedb2f7038ab7dd6dba71ab9b81a33", null ],
    [ "CS_SOLIDIFICATION_POST_CBULK_ADIM", "cs__solidification_8h.html#a09da5af8b74efa13e23f06e0f46d0000", null ],
    [ "CS_SOLIDIFICATION_POST_CELL_STATE", "cs__solidification_8h.html#aea5450b6b765c331a07fa7962082c0ae", null ],
    [ "CS_SOLIDIFICATION_POST_CLIQ", "cs__solidification_8h.html#a4281f391ffcd35077493fb4417728b59", null ],
    [ "CS_SOLIDIFICATION_POST_ENTHALPY", "cs__solidification_8h.html#aa45423a24ad5085693c938c292c12de9", null ],
    [ "CS_SOLIDIFICATION_POST_LIQUIDUS_TEMPERATURE", "cs__solidification_8h.html#aeedd83381c81f7bfbd992497800ab46c", null ],
    [ "CS_SOLIDIFICATION_POST_SEGREGATION_INDEX", "cs__solidification_8h.html#a5d25238383ba868c2f7f02a17eb44ab5", null ],
    [ "CS_SOLIDIFICATION_POST_SOLIDIFICATION_RATE", "cs__solidification_8h.html#ab6951ea065c7eceb1b161d92ea1bd3f5", null ],
    [ "CS_SOLIDIFICATION_USE_ENTHALPY_VARIABLE", "cs__solidification_8h.html#a4445fb75dac9ac4fdc4b6e56ddf705d4", null ],
    [ "CS_SOLIDIFICATION_USE_EXTRAPOLATION", "cs__solidification_8h.html#a0bfe68a6b794ad5280f3170868d7da06", null ],
    [ "CS_SOLIDIFICATION_WITH_PENALIZED_EUTECTIC", "cs__solidification_8h.html#a8694553071cca34d462ab4027d999d31", null ],
    [ "CS_SOLIDIFICATION_WITH_SOLUTE_SOURCE_TERM", "cs__solidification_8h.html#aab5002e17d27ed33b5803db5558e47b2", null ],
    [ "cs_solidification_func_t", "cs__solidification_8h.html#a426edc9b4c370bf2d60143bc28b700fb", null ],
    [ "cs_solidification_model_t", "cs__solidification_8h.html#a847fc9cd88ade8ed8fec05302493283e", [
      [ "CS_SOLIDIFICATION_MODEL_STEFAN", "cs__solidification_8h.html#a847fc9cd88ade8ed8fec05302493283ead310f2165a98a65537bc44be2a1e96ea", null ],
      [ "CS_SOLIDIFICATION_MODEL_VOLLER_PRAKASH_87", "cs__solidification_8h.html#a847fc9cd88ade8ed8fec05302493283ea72f4e36c43398be62f5f82d1eb4001a0", null ],
      [ "CS_SOLIDIFICATION_MODEL_VOLLER_NL", "cs__solidification_8h.html#a847fc9cd88ade8ed8fec05302493283ea5777c96d7b0146f9ab97487956edf7dd", null ],
      [ "CS_SOLIDIFICATION_MODEL_BINARY_ALLOY", "cs__solidification_8h.html#a847fc9cd88ade8ed8fec05302493283ea23776cc28184da5c0a1e18793d3d6632", null ],
      [ "CS_SOLIDIFICATION_N_MODELS", "cs__solidification_8h.html#a847fc9cd88ade8ed8fec05302493283eacd06fa59042aac5c895f36a76add9538", null ]
    ] ],
    [ "cs_solidification_state_t", "cs__solidification_8h.html#ab4298ec32d264db8112dea50e5497c3b", [
      [ "CS_SOLIDIFICATION_STATE_SOLID", "cs__solidification_8h.html#ab4298ec32d264db8112dea50e5497c3ba11d553eb8fd223ae636d904153c39a2d", null ],
      [ "CS_SOLIDIFICATION_STATE_MUSHY", "cs__solidification_8h.html#ab4298ec32d264db8112dea50e5497c3bae70b73f5c817cae2861dccd7ab876f45", null ],
      [ "CS_SOLIDIFICATION_STATE_LIQUID", "cs__solidification_8h.html#ab4298ec32d264db8112dea50e5497c3bade547a363b4a7a0076c7f61ea30ac792", null ],
      [ "CS_SOLIDIFICATION_STATE_EUTECTIC", "cs__solidification_8h.html#ab4298ec32d264db8112dea50e5497c3bae842024a96a086121827d561cd1cbead", null ],
      [ "CS_SOLIDIFICATION_N_STATES", "cs__solidification_8h.html#ab4298ec32d264db8112dea50e5497c3ba366ae1d85364e535f851936de75362a8", null ]
    ] ],
    [ "cs_solidification_strategy_t", "cs__solidification_8h.html#a9a11ab690b2f45b6712298ef199781a4", [
      [ "CS_SOLIDIFICATION_STRATEGY_LEGACY", "cs__solidification_8h.html#a9a11ab690b2f45b6712298ef199781a4a0d611113cda237cf3b2cbf29e983e830", null ],
      [ "CS_SOLIDIFICATION_STRATEGY_TAYLOR", "cs__solidification_8h.html#a9a11ab690b2f45b6712298ef199781a4a0db3938bb891879d3451acece02147b3", null ],
      [ "CS_SOLIDIFICATION_STRATEGY_PATH", "cs__solidification_8h.html#a9a11ab690b2f45b6712298ef199781a4a719293aeb828af4bf0463201698eca75", null ],
      [ "CS_SOLIDIFICATION_N_STRATEGIES", "cs__solidification_8h.html#a9a11ab690b2f45b6712298ef199781a4aa0a322acbffdc3cb958d6801d261abcd", null ]
    ] ],
    [ "cs_solidification_activate", "cs__solidification_8h.html#aabb4a1302df9167c7edbfbce1907a911", null ],
    [ "cs_solidification_check_binary_alloy_model", "cs__solidification_8h.html#a1dba326f70aeeecc800b4a6ee55d5e08", null ],
    [ "cs_solidification_check_stefan_model", "cs__solidification_8h.html#a610decffda68ea7da76a3c53db9ee4ad", null ],
    [ "cs_solidification_check_voller_model", "cs__solidification_8h.html#a1501389caf2179e13615b19e04a8662d", null ],
    [ "cs_solidification_compute", "cs__solidification_8h.html#a0f489dec0463d2309d825df87c68a3b5", null ],
    [ "cs_solidification_destroy_all", "cs__solidification_8h.html#a93ad2dfce76de24392235a237438d7a1", null ],
    [ "cs_solidification_extra_op", "cs__solidification_8h.html#a5a119e288d9de10dba56cbc7383267aa", null ],
    [ "cs_solidification_extra_post", "cs__solidification_8h.html#aafad3b15b18f023f7b253f1c4b897f6c", null ],
    [ "cs_solidification_finalize_setup", "cs__solidification_8h.html#a9ed273ffbebed1f2113505272c403d68", null ],
    [ "cs_solidification_get_binary_alloy_struct", "cs__solidification_8h.html#a142b6eb9648f915f3883d7aa445e1d65", null ],
    [ "cs_solidification_get_stefan_struct", "cs__solidification_8h.html#add3919a61d6c694c20eb327b3ab52dd9", null ],
    [ "cs_solidification_get_structure", "cs__solidification_8h.html#a6e734288fe38d042252f84e975715724", null ],
    [ "cs_solidification_get_voller_struct", "cs__solidification_8h.html#ac98746051a60bbcb2c86611a689b4a94", null ],
    [ "cs_solidification_init_setup", "cs__solidification_8h.html#a8aed8bf87ab13a52b0c8ed86d2d53a43", null ],
    [ "cs_solidification_init_values", "cs__solidification_8h.html#a5eaa7753944eb64e8192269b8d61d1e8", null ],
    [ "cs_solidification_is_activated", "cs__solidification_8h.html#ac9b4ea778d6477e677e68701a8ad4321", null ],
    [ "cs_solidification_log_setup", "cs__solidification_8h.html#accdf9de2c4023ba069d188860608eceb", null ],
    [ "cs_solidification_set_binary_alloy_model", "cs__solidification_8h.html#a9e8e8300a85460c3a9836e61508cfd65", null ],
    [ "cs_solidification_set_forcing_eps", "cs__solidification_8h.html#aed23a16562befe5af4b712c242b0a92c", null ],
    [ "cs_solidification_set_kozeny_carman_parameters", "cs__solidification_8h.html#ad0a8604a08fdbb010a874413b44c6610", null ],
    [ "cs_solidification_set_segr_functions", "cs__solidification_8h.html#ae42bba458637466963a9490e8b7aa8fd", null ],
    [ "cs_solidification_set_stefan_model", "cs__solidification_8h.html#aca386eb2d86482c2e6edd0f2e810ecb0", null ],
    [ "cs_solidification_set_strategy", "cs__solidification_8h.html#a1d002dac39889533773667f013057a7e", null ],
    [ "cs_solidification_set_verbosity", "cs__solidification_8h.html#aa039315ac787bf70f473c3210468ab9b", null ],
    [ "cs_solidification_set_voller_model", "cs__solidification_8h.html#afc0bf738c18e4d2437f8a5cde185e629", null ],
    [ "cs_solidification_set_voller_model_no_velocity", "cs__solidification_8h.html#ad386378ffef1a53c1d782431bdeb41fc", null ]
];
